| operate_set | R Documentation |
Performs intersection (%intersect%) and union (%union%) on the
dates or date-times implied by messy date class objects, treating each
as the (day-granularity) set of dates it expands to. Both return a
plain character vector of the individual member dates.
For a union that instead returns an mdate object in its most
succinct (contracted) notation, e.g. a range rather than a list of
every day within it, use + (see ?operate_arithmetic) instead.
e1 %intersect% e2
## S3 method for class 'mdate'
e1 %intersect% e2
e1 %union% e2
## S3 method for class 'mdate'
e1 %union% e2
e1, e2 |
Messy date or other class objects |
A vector of the same mode for %intersect%,
or a common mode for %union%.
%intersect% : Find intersection of sets of messy dates
%union% : Find union of sets of messy dates
as_messydate("2012-01-01..2012-01-20") %intersect% as_messydate("2012-01")
as_messydate("2012-01-01..2012-01-20") %union% as_messydate("2012-01")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.