| class_methods | R Documentation |
mdate objectsThese methods let mdate vectors behave like ordinary character vectors
for subsetting, replacement, concatenation, and repetition,
while ensuring the result remains a validated mdate object.
## S3 method for class 'mdate'
x[..., drop = TRUE]
## S3 replacement method for class 'mdate'
x[i, ...] <- value
## S3 method for class 'mdate'
x[[...]]
## S3 replacement method for class 'mdate'
x[[i, ...]] <- value
## S3 method for class 'mdate'
c(...)
## S3 method for class 'mdate'
rep(x, ...)
x |
An |
drop |
Included for consistency with the default |
i, ... |
Index or indices, as for the default methods; for |
value |
A replacement value, coerced to |
An mdate object, except for c(), which returns the (unclassed)
result when called on a single object.
d <- as_messydate(c("2012-01-01", "2012-02-01", "2012-03-01"))
d[2]
d[2] <- "2012-02-02"
c(d, as_messydate("2012-04-01"))
rep(d, 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.